diff src/keyboard.c @ 88120:3996a7930718

Merge from emacs--devo--0 Patches applied: * emacs--devo--0 (patch 865) - Update from CVS Revision: emacs@sv.gnu.org/emacs--multi-tty--0--patch-45
author Miles Bader <miles@gnu.org>
date Thu, 30 Aug 2007 02:03:47 +0000
parents 7c8832009d31 5b644ae74c91
children 0ce482dc32a6
line wrap: on
line diff
--- a/src/keyboard.c	Wed Aug 29 04:01:43 2007 +0000
+++ b/src/keyboard.c	Thu Aug 30 02:03:47 2007 +0000
@@ -8096,10 +8096,11 @@
 
 static int ntool_bar_items;
 
 /* The symbols `tool-bar', and `:image'.  */
 
 extern Lisp_Object Qtool_bar;
 Lisp_Object QCimage;
+Lisp_Object Qrtl;
 
 /* Function prototypes.  */
 
@@ -8385,6 +8386,9 @@
 	/* Value is either a single image specification or a vector
 	   of 4 such specifications for the different button states.  */
 	PROP (TOOL_BAR_ITEM_IMAGES) = value;
+      else if (EQ (key, Qrtl))
+        /* ':rtl STRING' */
+	PROP (TOOL_BAR_ITEM_RTL_IMAGE) = value;
     }
 
   /* If got a filter apply it on binding.  */
@@ -11624,6 +11628,9 @@
   staticpro (&Qhelp_echo);
   Qhelp_echo = intern ("help-echo");
 
+  staticpro (&Qrtl);
+  Qrtl = intern (":rtl");
+
   staticpro (&item_properties);
   item_properties = Qnil;
@@ -8096,10 +8096,11 @@
 static int ntool_bar_items;
 
-/* The symbols `tool-bar', and `:image'.  */
+/* The symbols `tool-bar', `:image' and `:rtl'.  */
 
 extern Lisp_Object Qtool_bar;